
rm(list=ls())

library(ggplot2)
library(viridis)
library(patchwork)
library(here)

respiration_df<-read.table(file = "respiration_data_frame_temperature.txt")

########################## calculate respiration

respiration_df$slope<-respiration_df$slope * respiration_df$SDR_well_volume * 10^-6  # micromol

respiration_df<-respiration_df[respiration_df$life_stage=="C5",]

min(respiration_df$slope)

max(respiration_df$slope)

# the response variable slope has very small values (µMol per minute) and is multiplied with a large constant 100000,
# the sign function is included to preserve the sign after log transformation, this to include all measurement errors, also when metabolic rate is positive even though impossible
# a 1 is added as constant for instances when metabolic rate is 0
# 100000 corresponds to 100000/(24*64) = approximately 65 days worth of respiration

# to convert to daily rates:
scaling_factor <- (100000/(24*64))

respiration_df$slope <- sign(respiration_df$slope*100000) * log(abs(respiration_df$slope*100000) + 1)

#### calculate mean respiration of individual at time i for each temperature

length(unique(respiration_df$unique_ID)) # 179

respiration_df_s<-split(respiration_df, interaction(respiration_df$time, respiration_df$temperature, respiration_df$unique_ID))

df<-data.frame(slope=unlist(lapply(1:153582, function(x) mean(respiration_df_s[[x]]$slope))),
               temperature=unlist(lapply(1:153582, function(x) respiration_df_s[[x]]$temperature[1])),
               unique_ID=unlist(lapply(1:153582, function(x) respiration_df_s[[x]]$unique_ID[1])),
               station=unlist(lapply(1:153582, function(x) respiration_df_s[[x]]$station[1])),
               dw=unlist(lapply(1:153582, function(x) respiration_df_s[[x]]$dw[1])),
               species=unlist(lapply(1:153582, function(x) respiration_df_s[[x]]$species[1])),
               time=unlist(lapply(1:153582, function(x) respiration_df_s[[x]]$time[1])))

df<-na.omit(df)

df_s<-split(df, df$time)

n_obs<-unlist(lapply(1:286, function(x) nrow(df_s[[x]])))   

n_obs/3

#### fit models and extract adjusted R2 across time

adj.R2<-round(unlist(lapply(1:286, function(x) summary(lm(slope~ log(temperature+1)  + species + log(dw), na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)
adj.R2_dw<-round(unlist(lapply(1:286, function(x) summary(lm(slope~ log(dw), na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)
adj.R2_species<-round(unlist(lapply(1:286, function(x) summary(lm(slope~ species, na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)
adj.R2_temperature<-round(unlist(lapply(1:286, function(x) summary(lm(slope~ log(temperature+1), na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)
adj.R2_null<-round(unlist(lapply(1:286, function(x) summary(lm(slope~ 1, na.action = na.fail,data = df_s[[x]]))$adj.r.squared)),3)

#### plot adjusted R2 across time

time<-unique(df$time)

df_adjusted_R2 <- data.frame(time = c(time, time, time, time, time),
                        adj.R2 = c(adj.R2, adj.R2_dw, adj.R2_species, adj.R2_temperature, adj.R2_null),
                        model_set = rep(c("All variables", "Dry weight", "Species", "Temperature", "Null"), rep(length(time),5)))

df_adjusted_R2$model_set <- factor(df_adjusted_R2$model_set, levels = c("All variables", "Dry weight", "Species", "Temperature", "Null"))

adjusted_R2_fig <- ggplot(df_adjusted_R2, aes(x=time, y=adj.R2, color = model_set))+
  geom_line(size = 1)+
  scale_color_viridis_d() +
  labs(x = "Time (minutes)", y = "Adjusted R-square", color = "Model set:", tag = "a)")+
  guides(color = guide_legend(nrow = 2))+
  scale_x_continuous(breaks = c(0, 20, 40, 60))+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_text(colour="black",size=10,angle=0,hjust=1,vjust=0,face="plain"),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(colour="black",size=10,angle=90,hjust=.5,vjust=.5,face="plain"),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10, hjust = 0, vjust = 0.5),
        panel.grid.major = element_line(color = "gray", linewidth = 0.4),
        panel.grid.minor = element_line(color = "gray", size = 0.2),
        plot.tag.position = "topleft",
        panel.background = element_rect(fill = "white", colour = "black"),
        legend.position = "bottom",
        legend.key = element_rect(fill = "lightgray"),
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical",
        plot.margin = margin(0,2,0,0))  


########## species across time, weighted per individual mean

df_s_species <- split(df, interaction(df$time, df$species))

df_species <- data.frame(slope=unlist(lapply(1:858, function(x) (exp(abs(mean(df_s_species[[x]]$slope))) - 1) / scaling_factor )),
                         species=unlist(lapply(1:858, function(x) df_s_species[[x]]$species[1])),
                         time=unlist(lapply(1:858, function(x) df_s_species[[x]]$time[1])),
                         se = unlist(lapply(1:858, function(x) sd((exp(abs(df_s_species[[x]]$slope)) - 1) / scaling_factor) / sqrt(length(df_s_species[[x]]$slope)))))

df_species$species <- factor(df_species$species)

species_fig <- ggplot(df_species, aes(x= time, y = slope, color = species, group = species))+
  geom_line(size = 1)+
  geom_ribbon(df_species, mapping = aes(x=time, ymin = slope - se*1.96, ymax = slope + se*1.96, group=species, fill = species), inherit.aes = FALSE, alpha=0.4)+
  scale_y_continuous(breaks = c(0, 0.2, 0.4, 0.6), limits = c(0, 0.6))+
  labs(x="Time (minutes)", color="Species:", y=bquote('Metabolic rate,'~µmol~O[2]~day^-1), tag = "b)")+
  scale_color_manual(values = c("#3B4992FF", "#EE0000FF", "#008B45FF"), labels=c(expression(italic("Calanus finmarchicus")), expression(italic("Calanus glacialis")), expression(italic("Metridia longa"))))+
  scale_fill_manual(values = c("#3B4992FF", "#EE0000FF", "#008B45FF"))+
  guides(fill = "none")+
  theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
        axis.text.y = element_text(size = 10),  
        axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
        axis.title.y = element_text(size = 10),
        plot.tag = element_text(size = 10),
        plot.title = element_text(size = 10, hjust = 0, vjust = 0.5),
        panel.grid.major = element_line(color = "gray", linewidth = 0.4),
        panel.grid.minor = element_line(color = "gray", size = 0.2),
        plot.tag.position = "topleft",
        panel.background = element_rect(fill = "white", colour = "black"),
        legend.position = "bottom",
        legend.key = element_rect(fill = "lightgray"),
        strip.text.y = element_text(face = c("italic"), size = 2),
        strip.text.x = element_text(face = c("bold"), size = 4),
        legend.text = element_text(size=10),
        legend.title = element_text(size = 10),
        legend.key.size = unit(10,"point"),
        legend.box = "vertical")  


######### temperature across time, weighted per individual mean, 
######### in "df" the mean of repeated measurements per individual has been calculated above

df_s_temperature <- split(df, interaction(df$time, df$temperature))

df_temperature <- data.frame(slope=unlist(lapply(1:858, function(x) (exp(abs(mean(df_s_temperature[[x]]$slope))) - 1) / scaling_factor )),
           temperature=unlist(lapply(1:858, function(x) df_s_temperature[[x]]$temperature[1])),
           time=unlist(lapply(1:858, function(x) df_s_temperature[[x]]$time[1])),
           se = unlist(lapply(1:858, function(x) sd((exp(abs(df_s_temperature[[x]]$slope)) - 1) / scaling_factor) / sqrt(length(df_s_temperature[[x]]$slope)))))

df_temperature$temperature <- factor(df_temperature$temperature)

temperature_fig<- ggplot(df_temperature, aes(x= time, y = slope, color = temperature, group = temperature))+
 geom_line(size = 1)+
 geom_ribbon(df_temperature, mapping = aes(x=time, ymin = slope - se*1.96, ymax = slope + se*1.96, group=temperature, fill = temperature), inherit.aes = FALSE, alpha=0.4)+
 scale_y_continuous(breaks = c(0, 0.2, 0.4, 0.6), limits = c(0, 0.6))+
 labs(x="Time (minutes)", color="Temperature °C:", y=NULL, tag = "c)")+
 scale_color_manual(values = c("#008EA0FF", "#FF6F00FF", "#C71000FF"))+
 scale_fill_manual(values = c("#008EA0FF", "#FF6F00FF", "#C71000FF"))+
 guides(fill="none")+
 theme(axis.text.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=.5,face="plain"),
      axis.text.y = element_blank(),  
      axis.title.x = element_text(colour="black",size=10,angle=0,hjust=.5,vjust=0,face="plain"),
      axis.title.y = element_blank(),
      plot.tag = element_text(size = 10),
      plot.title = element_text(size = 10, hjust = 0, vjust = 0.5),
      panel.grid.major = element_line(color = "gray", linewidth = 0.4),
      panel.grid.minor = element_line(color = "gray", size = 0.2),
      plot.tag.position = "topleft",
      panel.background = element_rect(fill = "white", colour = "black"),
      legend.position = "bottom",
      legend.background = element_blank(),
      legend.key = element_rect(fill = "lightgray"),
      strip.text.y = element_text(face = c("italic"), size = 2),
      strip.text.x = element_text(face = c("bold"), size = 4),
      legend.text = element_text(size=10),
      legend.title = element_text(size = 10),
      legend.key.size = unit(10,"point"),
      legend.box = "vertical")  


########## write figure

# png(file="Fig6.png", res = 900, height = 3.7, width = 6, units = 'in')

pdf(file="Fig6.pdf", height = 3.7, width = 6)

adjusted_R2_fig + species_fig + temperature_fig + plot_layout(guides = "collect") & theme(legend.position = "bottom", legend.box = "vertical")

dev.off()

